Dan Garrette @dhgarrette

Location

  Austin, USA

Role

  Semantics (nltk.sem, nltk.inference)

Active Range

  2007-2016

Peter Ljunglöf @heatherleaf

Location

  Gothenburg, Sweden

Role

  Parsing package maintainer: nltk.parse, nltk.featstruct, i.a.

Active Range

  2008-2015

Mikhail Korobov @kmike

Location

  Ekaterinburg, Russia

Role

  Porting NLTK to Python 3.

Active Range

  2012-2017

Alex Rudnick @alexrudnick

Active Range

  2010-2014

Edward Loper @edloper

Location

  Baltimore, USA

Active Range

  2001-2013

Ewan Klein @ewan-klein

Location

  Edinburgh, UK

Active Range

  2001-2016

Trevor Cohn @trevorcohn

Location

  Melbourne, Australia

Role

  parsing, classification

Active Range

  2003-2005

Pierpaolo Pantone @fievelk

Location

  Berlin, Germany

Active Range

  2014-2020

Nathan Schneider @nschneid

Location

  Georgetown, USA

Active Range

  2012-2018

Álvaro Justen @turicas

Active Range

  2012-2015

Morten M. Neergaard @xim

Active Range

  2011-2014